@@ -33,7 +33,7 @@ def cipher(message,key):
     message = x
 
     ki = 0
-    oi = randint(0,1)
+    oi = 1
     y = oi
 
     for i in range(len(message)):
@@ -109,6 +109,21 @@ Thank you to AmazingMech2418 (https://repl.it/@AmazingMech2418), for showing me
 Thank you StealthHydra179 (https://repl.it/@StealthHydra179), for being the only person who cared about programming in my school.\n\
 Thank you Giothecoder (https://repl.it/@Giothecoder), for being there when I needed you most.")
 
+def changelog():
+    print("=== ChangeLog ===\
+0.0.1 - Cipher was added, deciphering was unfinished\
+0.0.2 - Deciphering finished with lots of bugs\
+0.0.3 - Atticus Kuhn pointed out a safety bug, and thus it was patched\
+0.0.4 - Bugs fixes\
+0.0.5 - Added Credits\
+0.0.6 - AmazingMech2418 pointed out huge safety feature that should be added\
+0.0.7 - Bugs fixes\
+0.0.8 - Test Version\
+0.0.9 - Test Version\
+0.1.0 - Update 0.0.6 was revisited and implemented\
+0.1.1 - Added changelog\
+0.1.2 - Bug fixes")
+
 class InvalidKey(Exception):
     pass
 
